# aineko

## Quickstart

### Installation

Aineko uses [`poetry`](https://python-poetry.org/) as a dependency manager. To install poetry:

```
curl -sSL https://install.python-poetry.org | python3 -
```

To install dependencies, simply run:

```
poetry install
```

Alternatively, to use `pip`, use:

```
pip install -e .
```


## Roadmap
